@@ -1,9 +1,9 @@
 /*
- * "$Id: socket.c 8896 2009-11-20 01:27:57Z mike $"
+ * "$Id: socket.c 9061 2010-03-30 22:07:33Z mike $"
  *
  *   AppSocket backend for the Common UNIX Printing System (CUPS).
  *
- *   Copyright 2007-2009 by Apple Inc.
+ *   Copyright 2007-2010 by Apple Inc.
  *   Copyright 1997-2007 by Easy Software Products, all rights reserved.
  *
  *   These coded instructions, statements, and computer programs are the
@@ -406,6 +406,7 @@ main(int  argc,				/* I - Number of command-line arguments (6 or 7) */
 		      CUPS_LLCAST tbytes);
   }
 
+#ifdef __APPLE__
  /*
   * Wait up to 5 seconds to get any pending back-channel data...
   */
@@ -414,6 +415,7 @@ main(int  argc,				/* I - Number of command-line arguments (6 or 7) */
   while (wait_time >= time(&current_time))
     if (wait_bc(device_fd, wait_time - current_time) <= 0)
       break;
+#endif /* __APPLE__ */
 
   if (waiteof)
   {
@@ -505,5 +507,5 @@ wait_bc(int device_fd,			/* I - Socket */
 
 
 /*
- * End of "$Id: socket.c 8896 2009-11-20 01:27:57Z mike $".
+ * End of "$Id: socket.c 9061 2010-03-30 22:07:33Z mike $".
  */
