@@ -1,5 +1,5 @@
 /*
-* "$Id: usb-darwin.c 8810 2009-09-11 19:56:51Z mike $"
+* "$Id: usb-darwin.c 9157 2010-06-16 05:27:41Z mike $"
 *
 * Copyright 2005-2009 Apple Inc. All rights reserved.
 *
@@ -112,12 +112,6 @@ extern char **environ;
 
 #define DEBUG_WRITES 0
 
-/*
- * WAIT_EOF_DELAY is number of seconds we'll wait for responses from
- * the printer after we've finished sending all the data
- */
-#define WAIT_EOF_DELAY			7
-#define WAIT_SIDE_DELAY			3
 #define DEFAULT_TIMEOUT			5000L
 
 #define	USB_INTERFACE_KIND		CFUUIDGetUUIDBytes(kIOUSBInterfaceInterfaceID190)
@@ -247,11 +241,6 @@ typedef struct globals_s
   Boolean		wait_eof;
   int			drain_output;	/* Drain all pending output */
   int			bidi_flag;	/* 0=unidirectional, 1=bidirectional */
-
-  pthread_mutex_t	sidechannel_thread_mutex;
-  pthread_cond_t	sidechannel_thread_cond;
-  int			sidechannel_thread_stop;
-  int			sidechannel_thread_done;
 } globals_t;
 
 
@@ -292,9 +281,8 @@ static void status_timer_cb(CFRunLoopTimerRef timer, void *info);
 #if defined(__i386__) || defined(__x86_64__)
 static pid_t	child_pid;		/* Child PID */
 static void run_legacy_backend(int argc, char *argv[], int fd);	/* Starts child backend process running as a ppc executable */
-#endif /* __i386__ || __x86_64__ */
-static int	job_canceled = 0;	/* Was the job canceled? */
 static void sigterm_handler(int sig);	/* SIGTERM handler */
+#endif /* __i386__ || __x86_64__ */
 
 #ifdef PARSE_PS_ERRORS
 static const char *next_line (const char *buffer);
@@ -345,7 +333,6 @@ print_device(const char *uri,		/* I - Device URI */
   UInt32	  bytes;		/* Bytes written */
   struct timeval  *timeout,		/* Timeout pointer */
 		  stimeout;		/* Timeout for select() */
-  struct timespec cond_timeout;		/* pthread condition timeout */
 
 
  /*
@@ -374,12 +361,12 @@ print_device(const char *uri,		/* I - Device URI */
 
   if (!g.make || !g.model)
   {
-    _cupsLangPuts(stderr, _("ERROR: Fatal USB error!\n"));
+    _cupsLangPuts(stderr, _("ERROR: Fatal USB error\n"));
 
     if (!g.make)
-      fputs("DEBUG: USB make string is NULL!\n", stderr);
+      fputs("DEBUG: USB make string is NULL\n", stderr);
     if (!g.model)
-      fputs("DEBUG: USB model string is NULL!\n", stderr);
+      fputs("DEBUG: USB model string is NULL\n", stderr);
 
     return (CUPS_BACKEND_STOP);
   }
@@ -432,7 +419,7 @@ print_device(const char *uri,		/* I - Device URI */
         strlcpy(print_buffer, "USB class driver", sizeof(print_buffer));
 
       fputs("STATE: +apple-missing-usbclassdriver-error\n", stderr);
-      _cupsLangPuts(stderr, _("ERROR: Fatal USB error!\n"));
+      _cupsLangPuts(stderr, _("ERROR: Fatal USB error\n"));
       fprintf(stderr, "DEBUG: Could not load %s\n", print_buffer);
 
       if (driverBundlePath)
@@ -461,9 +448,9 @@ print_device(const char *uri,		/* I - Device URI */
   fputs("STATE: -connecting-to-device\n", stderr);
 
   /*
-   * Now that we are "connected" to the port, catch SIGTERM so that we
+   * Now that we are "connected" to the port, ignore SIGTERM so that we
    * can finish out any page data the driver sends (e.g. to eject the
-   * current page...  Only catch SIGTERM if we are printing data from
+   * current page...  Only ignore SIGTERM if we are printing data from
    * stdin (otherwise you can't cancel raw jobs...)
    */
 
@@ -475,7 +462,7 @@ print_device(const char *uri,		/* I - Device URI */
     memset(&action, 0, sizeof(action));
 
     sigemptyset(&action.sa_mask);
-    action.sa_handler = sigterm_handler;
+    action.sa_handler = SIG_IGN;
     sigaction(SIGTERM, &action, NULL);
   }
 
@@ -489,16 +476,11 @@ print_device(const char *uri,		/* I - Device URI */
 
   if (have_sidechannel)
   {
-    g.sidechannel_thread_stop = 0;
-    g.sidechannel_thread_done = 0;
-
-    pthread_cond_init(&g.sidechannel_thread_cond, NULL);
-    pthread_mutex_init(&g.sidechannel_thread_mutex, NULL);
-
     if (pthread_create(&sidechannel_thread_id, NULL, sidechannel_thread, NULL))
     {
-      _cupsLangPuts(stderr, _("ERROR: Fatal USB error!\n"));
-      fputs("DEBUG: Couldn't create side-channel thread!\n", stderr);
+      _cupsLangPuts(stderr, _("ERROR: Fatal USB error\n"));
+      fputs("DEBUG: Couldn't create side-channel thread\n", stderr);
+      registry_close();
       return (CUPS_BACKEND_STOP);
     }
   }
@@ -515,8 +497,9 @@ print_device(const char *uri,		/* I - Device URI */
 
   if (pthread_create(&read_thread_id, NULL, read_thread, NULL))
   {
-    _cupsLangPuts(stderr, _("ERROR: Fatal USB error!\n"));
-    fputs("DEBUG: Couldn't create read thread!\n", stderr);
+    _cupsLangPuts(stderr, _("ERROR: Fatal USB error\n"));
+    fputs("DEBUG: Couldn't create read thread\n", stderr);
+    registry_close();
     return (CUPS_BACKEND_STOP);
   }
 
@@ -594,14 +577,16 @@ print_device(const char *uri,		/* I - Device URI */
 	if (errno == EINTR && total_bytes == 0)
 	{
 	  fputs("DEBUG: Received an interrupt before any bytes were "
-	        "written, aborting!\n", stderr);
+	        "written, aborting\n", stderr);
+          registry_close();
           return (CUPS_BACKEND_OK);
 	}
 	else if (errno != EAGAIN && errno != EINTR)
 	{
-	  _cupsLangPuts(stderr, _("ERROR: Unable to read print data!\n"));
+	  _cupsLangPuts(stderr, _("ERROR: Unable to read print data\n"));
 	  perror("DEBUG: select");
-	  return (CUPS_BACKEND_FAILED);
+	  registry_close();
+          return (CUPS_BACKEND_FAILED);
 	}
       }
 
@@ -641,8 +626,9 @@ print_device(const char *uri,		/* I - Device URI */
 
 	  if (errno != EAGAIN && errno != EINTR)
 	  {
-	    _cupsLangPuts(stderr, _("ERROR: Unable to read print data!\n"));
+	    _cupsLangPuts(stderr, _("ERROR: Unable to read print data\n"));
 	    perror("DEBUG: read");
+	    registry_close();
 	    return (CUPS_BACKEND_FAILED);
 	  }
 
@@ -675,7 +661,7 @@ print_device(const char *uri,		/* I - Device URI */
 
 	if (iostatus == kIOUSBTransactionTimeout)
 	{
-	  fputs("DEBUG: Got USB transaction timeout during write!\n", stderr);
+	  fputs("DEBUG: Got USB transaction timeout during write\n", stderr);
 	  iostatus = 0;
 	}
 
@@ -685,7 +671,7 @@ print_device(const char *uri,		/* I - Device URI */
 
 	else if (iostatus == kIOUSBPipeStalled)
 	{
-	  fputs("DEBUG: Got USB pipe stalled during write!\n", stderr);
+	  fputs("DEBUG: Got USB pipe stalled during write\n", stderr);
 
 	  bytes    = g.print_bytes;
 	  iostatus = (*g.classdriver)->WritePipe(g.classdriver, (UInt8*)print_ptr, &bytes, 0);
@@ -698,7 +684,7 @@ print_device(const char *uri,		/* I - Device URI */
 
 	else if (iostatus == kIOReturnAborted)
 	{
-	  fputs("DEBUG: Got return aborted during write!\n", stderr);
+	  fputs("DEBUG: Got USB return aborted during write\n", stderr);
 
 	  IOReturn err = (*g.classdriver)->Abort(g.classdriver);
 	  fprintf(stderr, "DEBUG: USB class driver Abort returned %x\n", err);
@@ -717,7 +703,7 @@ print_device(const char *uri,		/* I - Device URI */
 	  * Write error - bail if we don't see an error we can retry...
 	  */
 
-	  _cupsLangPuts(stderr, _("ERROR: Unable to send print data!\n"));
+	  _cupsLangPuts(stderr, _("ERROR: Unable to send print data\n"));
 	  fprintf(stderr, "DEBUG: USB class driver WritePipe returned %x\n",
 	          iostatus);
 
@@ -725,7 +711,7 @@ print_device(const char *uri,		/* I - Device URI */
 	  fprintf(stderr, "DEBUG: USB class driver Abort returned %x\n",
 	          err);
 
-	  status = job_canceled ? CUPS_BACKEND_FAILED : CUPS_BACKEND_STOP;
+	  status = CUPS_BACKEND_FAILED;
 	  break;
 	}
 	else if (bytes > 0)
@@ -746,86 +732,6 @@ print_device(const char *uri,		/* I - Device URI */
 
   fprintf(stderr, "DEBUG: Sent %lld bytes...\n", (off_t)total_bytes);
 
- /*
-  * Wait for the side channel thread to exit...
-  */
-
-  if (have_sidechannel)
-  {
-    close(CUPS_SC_FD);
-    pthread_mutex_lock(&g.readwrite_lock_mutex);
-    g.readwrite_lock = 0;
-    pthread_cond_signal(&g.readwrite_lock_cond);
-    pthread_mutex_unlock(&g.readwrite_lock_mutex);
-
-    g.sidechannel_thread_stop = 1;
-    pthread_mutex_lock(&g.sidechannel_thread_mutex);
-    if (!g.sidechannel_thread_done)
-    {
-     /*
-      * Wait for the side-channel thread to exit...
-      */
-
-      cond_timeout.tv_sec  = time(NULL) + WAIT_SIDE_DELAY;
-      cond_timeout.tv_nsec = 0;
-      if (pthread_cond_timedwait(&g.sidechannel_thread_cond,
-			         &g.sidechannel_thread_mutex,
-				 &cond_timeout) != 0)
-      {
-       /*
-	* Force the side-channel thread to exit...
-	*/
-
-	pthread_kill(sidechannel_thread_id, SIGTERM);
-      }
-    }
-    pthread_mutex_unlock(&g.sidechannel_thread_mutex);
-
-    pthread_join(sidechannel_thread_id, NULL);
-
-    pthread_cond_destroy(&g.sidechannel_thread_cond);
-    pthread_mutex_destroy(&g.sidechannel_thread_mutex);
-  }
-
-  pthread_cond_destroy(&g.readwrite_lock_cond);
-  pthread_mutex_destroy(&g.readwrite_lock_mutex);
-
- /*
-  * Signal the read thread to stop...
-  */
-
-  g.read_thread_stop = 1;
-
- /*
-  * Give the read thread WAIT_EOF_DELAY seconds to complete all the data. If
-  * we are not signaled in that time then force the thread to exit.
-  */
-
-  pthread_mutex_lock(&g.read_thread_mutex);
-
-  if (!g.read_thread_done)
-  {
-    cond_timeout.tv_sec = time(NULL) + WAIT_EOF_DELAY;
-    cond_timeout.tv_nsec = 0;
-
-    if (pthread_cond_timedwait(&g.read_thread_cond, &g.read_thread_mutex,
-                               &cond_timeout) != 0)
-    {
-     /*
-      * Force the read thread to exit...
-      */
-
-      g.wait_eof = 0;
-      pthread_kill(read_thread_id, SIGTERM);
-    }
-  }
-  pthread_mutex_unlock(&g.read_thread_mutex);
-
-  pthread_join(read_thread_id, NULL);	/* wait for the read thread to return */
-
-  pthread_cond_destroy(&g.read_thread_cond);
-  pthread_mutex_destroy(&g.read_thread_mutex);
-
  /*
   * Close the connection and input file and general clean up...
   */
@@ -898,11 +804,11 @@ static void *read_thread(void *reference)
 #endif
     }
     else if (readstatus == kIOUSBTransactionTimeout)
-      fputs("DEBUG: Got USB transaction timeout during write!\n", stderr);
+      fputs("DEBUG: Got USB transaction timeout during read\n", stderr);
     else if (readstatus == kIOUSBPipeStalled)
-      fputs("DEBUG: Got USB pipe stalled during read!\n", stderr);
+      fputs("DEBUG: Got USB pipe stalled during read\n", stderr);
     else if (readstatus == kIOReturnAborted)
-      fputs("DEBUG: Got return aborted during read!\n", stderr);
+      fputs("DEBUG: Got USB return aborted during read\n", stderr);
 
    /*
     * Make sure this loop executes no more than once every 250 miliseconds...
@@ -944,7 +850,12 @@ sidechannel_thread(void *reference)
     datalen = sizeof(data);
 
     if (cupsSideChannelRead(&command, &status, data, &datalen, 1.0))
-      continue;
+    {
+      if (status == CUPS_SC_STATUS_TIMEOUT)
+	continue;
+      else
+	break;
+    }
 
     switch (command)
     {
@@ -1029,12 +940,7 @@ sidechannel_thread(void *reference)
 	  break;
     }
   }
-  while (!g.sidechannel_thread_stop);
-
-  pthread_mutex_lock(&g.sidechannel_thread_mutex);
-  g.sidechannel_thread_done = 1;
-  pthread_cond_signal(&g.sidechannel_thread_cond);
-  pthread_mutex_unlock(&g.sidechannel_thread_mutex);
+  while (1);
 
   return NULL;
 }
@@ -1902,6 +1808,7 @@ static void run_legacy_backend(int argc,
     * Setup a SIGTERM handler then block it before forking...
     */
 
+    int			err;		/* posix_spawn result */
     struct sigaction	action;		/* POSIX signal action */
     sigset_t		newmask,	/* New signal mask */
 			oldmask;	/* Old signal mask */
@@ -1950,7 +1857,7 @@ static void run_legacy_backend(int argc,
 #  else
 	perror("DEBUG: Unable to set binary preference to ppc");
 #  endif /* __x86_64__ */
-	_cupsLangPrintf(stderr, _("Unable to use legacy USB class driver!\n"));
+	_cupsLangPrintf(stderr, _("Unable to use legacy USB class driver\n"));
 	exit(CUPS_BACKEND_STOP);
       }
     }
@@ -1968,11 +1875,12 @@ static void run_legacy_backend(int argc,
 
     my_argv[i] = NULL;
 
-    if (posix_spawn(&child_pid, usbpath, NULL, &attrs, my_argv, environ))
+    if ((err = posix_spawn(&child_pid, usbpath, NULL, &attrs, my_argv,
+                           environ)) != 0)
     {
       fprintf(stderr, "DEBUG: Unable to exec %s: %s\n", usbpath,
-              strerror(errno));
-      _cupsLangPrintf(stderr, _("Unable to use legacy USB class driver!\n"));
+              strerror(err));
+      _cupsLangPrintf(stderr, _("Unable to use legacy USB class driver\n"));
       exit(CUPS_BACKEND_STOP);
     }
 
@@ -1998,14 +1906,14 @@ static void run_legacy_backend(int argc,
     if (WIFSIGNALED(childstatus))
     {
       exitstatus = CUPS_BACKEND_STOP;
-      fprintf(stderr, "DEBUG: usb(legacy) backend %d crashed on signal %d!\n",
+      fprintf(stderr, "DEBUG: usb(legacy) backend %d crashed on signal %d\n",
               child_pid, WTERMSIG(childstatus));
     }
     else
     {
       if ((exitstatus = WEXITSTATUS(childstatus)) != 0)
 	fprintf(stderr,
-	        "DEBUG: usb(legacy) backend %d stopped with status %d!\n",
+	        "DEBUG: usb(legacy) backend %d stopped with status %d\n",
 		child_pid, exitstatus);
       else
 	fprintf(stderr, "DEBUG: usb(legacy) backend %d exited with no errors\n",
@@ -2020,8 +1928,6 @@ static void run_legacy_backend(int argc,
 
   exit(exitstatus);
 }
-#endif /* __i386__ || __x86_64__ */
-
 
 /*
  * 'sigterm_handler()' - SIGTERM handler.
@@ -2030,7 +1936,8 @@ static void run_legacy_backend(int argc,
 static void
 sigterm_handler(int sig)		/* I - Signal */
 {
-#if defined(__i386__) || defined(__x86_64__)
+  /* If we started a child process pass the signal on to it...
+   */
   if (child_pid)
   {
    /*
@@ -2048,19 +1955,14 @@ sigterm_handler(int sig)		/* I - Signal */
       exit(0);
     else
     {
-      fprintf(stderr, "DEBUG: Child crashed on signal %d!\n", status);
+      fprintf(stderr, "DEBUG: Child crashed on signal %d\n", status);
       exit(CUPS_BACKEND_STOP);
     }
   }
-#endif /* __i386__ || __x86_64__ */
-
- /*
-  * Otherwise just flag that the job has been canceled...
-  */
-
-  job_canceled = 1;
 }
 
+#endif /* __i386__ || __x86_64__ */
+
 
 #ifdef PARSE_PS_ERRORS
 /*
@@ -2226,5 +2128,5 @@ static void get_device_id(cups_sc_status_t *status,
 
 
 /*
- * End of "$Id: usb-darwin.c 8810 2009-09-11 19:56:51Z mike $".
+ * End of "$Id: usb-darwin.c 9157 2010-06-16 05:27:41Z mike $".
  */
