@@ -1,5 +1,5 @@
 /*
- * "$Id: dest.c 8789 2009-08-28 22:54:34Z mike $"
+ * "$Id: dest.c 9061 2010-03-30 22:07:33Z mike $"
  *
  *   User-defined destination (and option) support for the Common UNIX
  *   Printing System (CUPS).
@@ -33,7 +33,6 @@
  *                           server.
  *   appleCopyLocations()  - Copy the location history array.
  *   appleCopyNetwork()    - Get the network ID for the current location.
- *   appleGetDefault()     - Get the default printer for this location.
  *   appleGetPaperSize()   - Get the default paper size.
  *   appleGetPrinter()     - Get a printer from the history array.
  *   appleSetDefault()     - Set the default printer for this location.
@@ -54,7 +53,7 @@
 
 #include "debug.h"
 #include "globals.h"
-#include "pwgmedia.h"
+#include "pwg-private.h"
 #include <stdlib.h>
 #include <ctype.h>
 #include <sys/stat.h>
@@ -139,12 +138,17 @@ cupsAddDest(const char  *name,		/* I  - Destination name */
 
   if (!cupsGetDest(name, instance, num_dests, *dests))
   {
-    if (instance &&
-        (parent = cupsGetDest(name, NULL, num_dests, *dests)) == NULL)
+    if (instance && !cupsGetDest(name, NULL, num_dests, *dests))
       return (num_dests);
 
     dest = cups_add_dest(name, instance, &num_dests, dests);
 
+   /*
+    * Find the base dest again now the array has been realloc'd.
+    */
+
+    parent = cupsGetDest(name, NULL, num_dests, *dests);
+
     if (instance && parent && parent->num_options > 0)
     {
      /*
@@ -549,7 +553,7 @@ cupsGetNamedDest(http_t     *http,	/* I - Connection to server or @code CUPS_HTT
 
   if (!cups_get_sdests(http, op, name, 0, &dest))
   {
-    if (op == CUPS_GET_DEFAULT)
+    if (op == CUPS_GET_DEFAULT || (name && !set_as_default))
       return (NULL);
 
    /*
@@ -1109,8 +1113,8 @@ static char *				/* O - Default paper size */
 appleGetPaperSize(char *name,		/* I - Paper size name buffer */
                   int  namesize)	/* I - Size of buffer */
 {
-  CFStringRef		defaultPaperID;	/* Default paper ID */
-  _cups_pwg_media_t	*pwgmedia;	/* PWG media size */
+  CFStringRef	defaultPaperID;		/* Default paper ID */
+  _pwg_media_t	*pwgmedia;		/* PWG media size */
 
 
   defaultPaperID = CFPreferencesCopyAppValue(kDefaultPaperIDKey,
@@ -1120,7 +1124,7 @@ appleGetPaperSize(char *name,		/* I - Paper size name buffer */
       !CFStringGetCString(defaultPaperID, name, namesize,
 			  kCFStringEncodingUTF8))
     name[0] = '\0';
-  else if ((pwgmedia = _cupsPWGMediaByLegacy(name)) != NULL)
+  else if ((pwgmedia = _pwgMediaForLegacy(name)) != NULL)
     strlcpy(name, pwgmedia->pwg, namesize);
 
   if (defaultPaperID)
@@ -1288,6 +1292,9 @@ appleUseLastPrinter(void)
   CFPropertyListRef	uselast;	/* Use last printer preference value */
 
 
+  if (getenv("CUPS_DISABLE_APPLE_DEFAULT"))
+    return (0);
+
   if ((uselast = CFPreferencesCopyAppValue(kUseLastPrinterAsCurrentPrinterKey,
                                            kPMPrintingPreferences)) != NULL)
   {
@@ -2053,5 +2060,5 @@ cups_make_string(
 
 
 /*
- * End of "$Id: dest.c 8789 2009-08-28 22:54:34Z mike $".
+ * End of "$Id: dest.c 9061 2010-03-30 22:07:33Z mike $".
  */
