@@ -1,10 +1,9 @@
 /*
- * "$Id: ipp.h 8627 2009-05-13 21:39:17Z mike $"
+ * "$Id: ipp.h 9120 2010-04-23 18:56:34Z mike $"
  *
- *   Internet Printing Protocol definitions for the Common UNIX Printing
- *   System (CUPS).
+ *   Internet Printing Protocol definitions for CUPS.
  *
- *   Copyright 2007-2009 by Apple Inc.
+ *   Copyright 2007-2010 by Apple Inc.
  *   Copyright 1997-2006 by Easy Software Products.
  *
  *   These coded instructions, statements, and computer programs are the
@@ -64,7 +63,7 @@ extern "C" {
  * Types and structures...
  */
 
-typedef enum ipp_tag_e			/**** Format tags for attributes... ****/
+typedef enum ipp_tag_e			/**** Format tags for attributes ****/
 {
   IPP_TAG_ZERO = 0x00,			/* Zero tag - used for separators */
   IPP_TAG_OPERATION,			/* Operation group */
@@ -105,13 +104,13 @@ typedef enum ipp_tag_e			/**** Format tags for attributes... ****/
   IPP_TAG_COPY = -0x7fffffff-1		/* Bitflag for copied attribute values */
 } ipp_tag_t;
 
-typedef enum ipp_res_e			/**** Resolution units... ****/
+typedef enum ipp_res_e			/**** Resolution units ****/
 {
   IPP_RES_PER_INCH = 3,			/* Pixels per inch */
   IPP_RES_PER_CM			/* Pixels per centimeter */
 } ipp_res_t;
 
-typedef enum ipp_finish_e		/**** Finishings... ****/
+typedef enum ipp_finish_e		/**** Finishings ****/
 {
   IPP_FINISHINGS_NONE = 3,		/* No finishing */
   IPP_FINISHINGS_STAPLE,		/* Staple (any location) */
@@ -143,7 +142,7 @@ typedef enum ipp_finish_e		/**** Finishings... ****/
   IPP_FINISHINGS_BIND_BOTTOM		/* Bind on bottom */
 } ipp_finish_t;
 
-typedef enum ipp_orient_e		/**** Orientation... ****/
+typedef enum ipp_orient_e		/**** Orientation values ****/
 {
   IPP_PORTRAIT = 3,			/* No rotation */
   IPP_LANDSCAPE,			/* 90 degrees counter-clockwise */
@@ -151,14 +150,14 @@ typedef enum ipp_orient_e		/**** Orientation... ****/
   IPP_REVERSE_PORTRAIT			/* 180 degrees */
 } ipp_orient_t;
 
-typedef enum ipp_quality_e		/**** Qualities... ****/
+typedef enum ipp_quality_e		/**** Qualities ****/
 {
   IPP_QUALITY_DRAFT = 3,		/* Draft quality */
   IPP_QUALITY_NORMAL,			/* Normal quality */
   IPP_QUALITY_HIGH			/* High quality */
 } ipp_quality_t;
 
-typedef enum ipp_jstate_e		/**** Job States.... */
+typedef enum ipp_jstate_e		/**** Job states ****/
 {
   IPP_JOB_PENDING = 3,			/* Job is waiting to be printed */
   IPP_JOB_HELD,				/* Job is held for printing */
@@ -170,14 +169,14 @@ typedef enum ipp_jstate_e		/**** Job States.... */
 } ipp_jstate_t;
 #define IPP_JOB_CANCELLED IPP_JOB_CANCELED
 
-typedef enum ipp_pstate_e		/**** Printer States.... */
+typedef enum ipp_pstate_e		/**** Printer states ****/
 {
   IPP_PRINTER_IDLE = 3,			/* Printer is idle */
   IPP_PRINTER_PROCESSING,		/* Printer is working */
   IPP_PRINTER_STOPPED			/* Printer is stopped */
 } ipp_pstate_t;
 
-typedef enum ipp_state_e		/**** IPP states... ****/
+typedef enum ipp_state_e		/**** IPP states ****/
 {
   IPP_ERROR = -1,			/* An error occurred */
   IPP_IDLE,				/* Nothing is happening/request completed */
@@ -186,7 +185,7 @@ typedef enum ipp_state_e		/**** IPP states... ****/
   IPP_DATA				/* IPP request data needs to be sent/received */
 } ipp_state_t;
 
-typedef enum ipp_op_e			/**** IPP operations... ****/
+typedef enum ipp_op_e			/**** IPP operations ****/
 {
   IPP_PRINT_JOB = 0x0002,		/* Print a single file */
   IPP_PRINT_URI,			/* Print a single URL @private@ */
@@ -255,7 +254,7 @@ typedef enum ipp_op_e			/**** IPP operations... ****/
 #define CUPS_ADD_PRINTER	CUPS_ADD_MODIFY_PRINTER
 #define CUPS_ADD_CLASS		CUPS_ADD_MODIFY_CLASS
 
-typedef enum ipp_status_e		/**** IPP status codes... ****/
+typedef enum ipp_status_e		/**** IPP status codes ****/
 {
   IPP_OK = 0x0000,			/* successful-ok */
   IPP_OK_SUBST,				/* successful-ok-ignored-or-substituted-attributes */
@@ -405,6 +404,9 @@ struct ipp_s				/**** IPP Request/Response/Notification ****/
 
 /**** New in CUPS 1.2 ****/
   ipp_attribute_t *prev;		/* Previous attribute (for read) @since CUPS 1.2/Mac OS X 10.5@ */
+
+/**** New in CUPS 1.5 ****/
+  int		use;			/* Use count */
 };
 
 
@@ -498,5 +500,5 @@ extern ipp_tag_t	ippTagValue(const char *name) _CUPS_API_1_4;
 #endif /* !_CUPS_IPP_H_ */
 
 /*
- * End of "$Id: ipp.h 8627 2009-05-13 21:39:17Z mike $".
+ * End of "$Id: ipp.h 9120 2010-04-23 18:56:34Z mike $".
  */
