@@ -1,9 +1,9 @@
 /*
- * "$Id: classes.h 6649 2007-07-11 21:46:42Z mike $"
+ * "$Id: classes.h 9061 2010-03-30 22:07:33Z mike $"
  *
  *   Printer class definitions for the Common UNIX Printing System (CUPS).
  *
- *   Copyright 2007 by Apple Inc.
+ *   Copyright 2007-2010 by Apple Inc.
  *   Copyright 1997-2005 by Easy Software Products, all rights reserved.
  *
  *   These coded instructions, statements, and computer programs are the
@@ -21,10 +21,9 @@
 extern cupsd_printer_t	*cupsdAddClass(const char *name);
 extern void		cupsdAddPrinterToClass(cupsd_printer_t *c,
 			                       cupsd_printer_t *p);
-extern void		cupsdDeletePrinterFromClass(cupsd_printer_t *c,
+extern int		cupsdDeletePrinterFromClass(cupsd_printer_t *c,
 			                            cupsd_printer_t *p);
-extern void		cupsdDeletePrinterFromClasses(cupsd_printer_t *p);
-extern void		cupsdDeleteAllClasses(void);
+extern int		cupsdDeletePrinterFromClasses(cupsd_printer_t *p);
 extern cupsd_printer_t	*cupsdFindAvailablePrinter(const char *name);
 extern cupsd_printer_t	*cupsdFindClass(const char *name);
 extern void		cupsdLoadAllClasses(void);
@@ -33,5 +32,5 @@ extern void		cupsdUpdateImplicitClasses(void);
 
 
 /*
- * End of "$Id: classes.h 6649 2007-07-11 21:46:42Z mike $".
+ * End of "$Id: classes.h 9061 2010-03-30 22:07:33Z mike $".
  */
